import { DynamoDB } from 'aws-sdk';

const dynamoDb = new DynamoDB.DocumentClient();
const tableName = process.env.TABLE_NAME;

export const handler = async (event: any) => {
  const contactId = event.pathParameters?.contactId;

  try {
    if (contactId) {
      // Fetch specific contact
      const result = await dynamoDb
        .get({
          TableName: tableName!,
          Key: { contactId },
        })
        .promise();

      if (!result.Item) {
        return {
          statusCode: 404,
          body: JSON.stringify({ error: 'Contact not found' }),
        };
      }

      return {
        statusCode: 200,
        body: JSON.stringify(result.Item),
      };
    } else {
      // Fetch all contacts
      const result = await dynamoDb
        .scan({
          TableName: tableName!,
        })
        .promise();

      return {
        statusCode: 200,
        body: JSON.stringify(result.Items || []),
      };
    }
  } catch (error) {
    console.error('Error fetching contacts:', error);
    return {
      statusCode: 500,
      body: JSON.stringify({ error: 'Could not fetch contacts' }),
    };
  }
};
