import { createApi, fetchBaseQuery } from '@reduxjs/toolkit/query/react';
import { baseURL } from 'constants/index';

export const apiSlice = createApi({
  reducerPath: 'api',
  tagTypes: ['Auth', 'Contact', 'Label'],
  baseQuery: fetchBaseQuery({
    baseUrl: baseURL,
    prepareHeaders: (headers, { getState }) => {
      const token = (getState() as any).auth.token;
      if (token) {
        headers.set('Authorization', `Bearer ${token}`);
      }
      return headers;
    },
  }),
  endpoints: (builder) => ({
    getContacts: builder.query({
      query: () => '/contacts',
    }),
    getContactById: builder.query({
      query: (id) => `/contacts/${id}`,
    }),
    createContact: builder.mutation({
      query: (contact) => ({
        url: '/contacts',
        method: 'POST',
        body: contact,
      }),
      invalidatesTags: ['Contact'],
    }),
  }),
});
export const {
  useGetContactsQuery,
  useGetContactByIdQuery,
  useCreateContactMutation,
} = apiSlice;
